@@ -5,7 +5,7 @@ import git_portfolio.domain.pull_request as pr
 import git_portfolio.request_objects.issue_list as il
 import git_portfolio.responses as res
 import git_portfolio.use_cases.gh as gh
-import git_portfolio.use_cases.gh_list_issue as li
+import git_portfolio.views as views
 
 
 class GhCreatePrUseCase(gh.GhUseCase):
@@ -20,9 +20,7 @@ class GhCreatePrUseCase(gh.GhUseCase):
         """Create pull requests."""
         github_service_method = "create_pull_request_from_repo"
         if pr_obj.link_issues:
-            response = li.GhListIssueUseCase(
-                self.config_manager, self.github_service, github_repo
-            ).execute(request_object)
+            response = views.issues(github_repo, self.github_service, request_object)
             if isinstance(response, res.ResponseSuccess):
                 custom_pr = self.github_service.link_issues(pr_obj, response.value)
         try:
